@@ -1,13 +1,4 @@
-/*-- gtk-noop-toggle.h --*/
-/*
-    This software may only be used by you under license from AT&T Corp.
-    ("AT&T").  A copy of AT&T's Source Code Agreement is available at
-    AT&T's Internet website having the URL:
-    <http://www.research.att.com/areas/stat/ggobi/license.html>
-    If you received this software without first entering into a license
-    with AT&T, you have an infringing copy of this software and cannot use
-    it without violating AT&T's intellectual property rights.
-*/
+/*-- noop-toggle.h --*/
 
 #ifndef _INC_NOOP_TOGGLE_BUTTON_H
 #define _INC_NOOP_TOGGLE_BUTTON_H
