@@ -1,13 +1,19 @@
 /*-- types.h --*/
 /*
-    This software may only be used by you under license from AT&T Corp.
-    ("AT&T").  A copy of AT&T's Source Code Agreement is available at
-    AT&T's Internet website having the URL:
-    <http://www.research.att.com/areas/stat/ggobi/license.html>
-    If you received this software without first entering into a license
-    with AT&T, you have an infringing copy of this software and cannot use
-    it without violating AT&T's intellectual property rights.
+ * ggobi
+ * Copyright (C) AT&T, Duncan Temple Lang, Dianne Cook 1999-2005
+ *
+ * ggobi is free software; you may use, redistribute, and/or modify it
+ * under the terms of the Common Public License, which is distributed
+ * with the source code and displayed on the ggobi web site, 
+ * www.ggobi.org.  For more information, contact the authors:
+ *
+ *   Deborah F. Swayne   dfs@research.att.com
+ *   Di Cook             dicook@iastate.edu
+ *   Duncan Temple Lang  duncan@wald.ucdavis.edu
+ *   Andreas Buja        andreas.buja@wharton.upenn.edu
 */
+
 #ifndef TYPES_H
 #define TYPES_H
 
@@ -71,19 +77,15 @@ typedef struct {
 /* The symbolic edge description which keeps the endpoints as record ids */
 typedef gchar *RecordKey;
 typedef struct {
-
   RecordKey a;
   RecordKey b;
   gint jpartner;
-
 } SymbolicEndpoints;
 typedef struct {
   gchar *a;
   gchar *b;
   gint jcase;
 } SortableEndpoints;
-
-
 typedef struct {
   endpointsd *endpoints;
   struct _datad *data;
