@@ -82,14 +82,22 @@ static GtkItemFactoryEntry menu_items[] = {
        0 },
   };
 
-static const gchar *const dsource_lbl[] = {"Unweighted", "D from variable"};
+static const gchar *const dsource_lbl[] = {
+  "Unweighted graph dist", 
+  "D from variable"
+};
 static const gchar *const metric_lbl[] = {"Metric MDS", "Nonmetric MDS"};
 static const gchar *const kruskal_lbl[] = {"Kruskal", "Classic"};
 static const gchar *const groups_lbl[] = {
-  "Within groups",
-  "Between groups",
-  "Anchors scale",
-  "Anchors fixed"};
+  "Use all distances",
+  "Use distances within groups",
+  "Use distances between groups",
+};
+static const gchar *const anchor_lbl[] = {
+  "No anchor",
+  "Scaled",
+  "Fixed",
+};
 static const gchar *const constrained_lbl[] = {
   "No variables frozen",
   "First variable frozen",
@@ -106,7 +114,7 @@ show_ggvis_window (GtkWidget *widget, PluginInstance *inst)
   if (inst->data == NULL) {
     ggvisd *ggv = (ggvisd *) g_malloc (sizeof (ggvisd));
 
-    ggvis_init (ggv);
+    ggvis_init (ggv, inst->gg);
     ggv_histogram_init (ggv, inst->gg);
 
     create_ggvis_window (ggv, inst);
@@ -146,6 +154,7 @@ ggv_datad_set_cb (GtkWidget *cl, gint row, gint column,
   datad *d;
   GSList *l;
   gchar *clname = gtk_widget_get_name (GTK_WIDGET(cl));
+  gint k;
 
   gtk_clist_get_text (GTK_CLIST (cl), row, 0, &dname);
   for (l = gg->d; l; l = l->next) {
@@ -153,6 +162,13 @@ ggv_datad_set_cb (GtkWidget *cl, gint row, gint column,
     if (strcmp (d->name, dname) == 0) {
       if (strcmp (clname, "nodeset") == 0) {
         ggv->dsrc = d;
+
+        /* Once dsrc has been defined, the anchor groups can be
+	   initialized */
+        vectorb_realloc (&ggv->anchor_group, d->nclusters);
+        for (k=0; k<d->nclusters; k++)
+          ggv->anchor_group.els[k] = false;
+
       } else if (strcmp (clname, "edgeset") == 0) {
         ggv->e = d;
       }
@@ -165,9 +181,15 @@ static void
 ggv_clist_datad_added_cb (ggobid *gg, datad *d, void *clist)
 {
   gchar *row[1];
-  GtkWidget *swin = (GtkWidget *)
+  GtkWidget *swin;
+  gchar *clname;
+
+  if (clist == NULL)
+    return;
+
+  swin = (GtkWidget *)
     gtk_object_get_data (GTK_OBJECT (clist), "datad_swin");
-  gchar *clname = gtk_widget_get_name (GTK_WIDGET(clist));
+  clname = gtk_widget_get_name (GTK_WIDGET(clist));
 
   if (strcmp (clname, "nodeset") == 0 && d->rowIds != NULL) {
     row[0] = g_strdup (d->name);
@@ -189,12 +211,13 @@ create_ggvis_window(ggvisd *ggv, PluginInstance *inst)
   GtkWidget *window, *main_vbox, *vbox_params;
   GtkWidget *notebook, *varnotebook, *opt, *metric_opt;
   GtkWidget *label, *frame, *btn, *vbox, *hbox, *vb, *hscale, *table, *hb;
+  GtkWidget *menu, *child, *radio, *radio1, *radio2;
+  GList *children, *list;
+  GSList *group;
   GtkObject *adj, *Dtarget_adj, *isotonic_mix_adj;
-  gint top;
+  gint i, top;
   GtkAccelGroup *ggv_accel_group;
   GtkWidget *menubar;
-  GtkTooltips *tips;
-  GtkWidget *entry;
   /*-- for lists of datads --*/
   gchar *clist_titles[2] = {"node sets", "edge sets"};
   datad *d;
@@ -203,7 +226,7 @@ create_ggvis_window(ggvisd *ggv, PluginInstance *inst)
   gchar *row[1];
   GSList *l;
 
-  tips = gtk_tooltips_new ();
+  ggv->tips = gtk_tooltips_new ();
 
   window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
   gtk_object_set_data (GTK_OBJECT (window), "ggvisd", ggv);
@@ -299,11 +322,79 @@ create_ggvis_window(ggvisd *ggv, PluginInstance *inst)
   gtk_container_add (GTK_CONTAINER (swin), clist);
   gtk_box_pack_start (GTK_BOX (hbox), swin, true, true, 2);
 
-
-
-  label = gtk_label_new ("Specify datasets");
+  label = gtk_label_new ("Datasets");
   gtk_notebook_append_page (GTK_NOTEBOOK (notebook), hbox, label);
 
+  /*-- Task controls --*/
+
+  vbox = gtk_hbox_new (false, 1);
+  gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
+
+  frame = gtk_frame_new ("Task Definition");
+  gtk_container_set_border_width (GTK_CONTAINER (frame), 1);
+  gtk_box_pack_start (GTK_BOX (vbox), frame, true, true, 2);
+
+  vb = gtk_vbox_new (false, 1);
+  gtk_container_set_border_width (GTK_CONTAINER (vb), 3);
+  gtk_container_add (GTK_CONTAINER(frame), vb);
+
+  radio1 = gtk_radio_button_new_with_label (NULL, "Dissimilarity analysis");
+  gtk_widget_set_name (GTK_WIDGET(radio1), "MDS");
+  gtk_tooltips_set_tip (GTK_TOOLTIPS (ggv->tips), radio1,
+    "Perform multidimensional scaling (MDS) for the purpose of dissimilarity analysis; dissimilarities (distances) are provided as an edge variable.",
+    NULL);
+  group = gtk_radio_button_group (GTK_RADIO_BUTTON (radio1));
+  radio2 = gtk_radio_button_new_with_label (group, "Graph layout");
+  gtk_widget_set_name (GTK_WIDGET(radio2), "GRAPH_LAYOUT");
+  gtk_tooltips_set_tip (GTK_TOOLTIPS (ggv->tips), radio2,
+    "Perform multidimensional scaling (MDS) for the purpose of laying out a graph.",
+    NULL);
+
+  GTK_TOGGLE_BUTTON(radio1)->active = (ggv->mds_task == DissimAnalysis);
+  GTK_TOGGLE_BUTTON(radio2)->active = (ggv->mds_task == GraphLayout);
+
+  gtk_signal_connect (GTK_OBJECT (radio1), "toggled",
+    GTK_SIGNAL_FUNC (ggv_task_cb), inst);
+  gtk_signal_connect (GTK_OBJECT (radio2), "toggled",
+    GTK_SIGNAL_FUNC (ggv_task_cb), inst);
+
+  gtk_box_pack_start (GTK_BOX (vb), radio1, true, true, 2);
+  gtk_box_pack_start (GTK_BOX (vb), radio2, true, true, 2);
+
+  frame = gtk_frame_new ("Graph Layout Options");
+  gtk_container_set_border_width (GTK_CONTAINER (frame), 1);
+  gtk_box_pack_start (GTK_BOX (vbox), frame, true, true, 2);
+
+  vb = gtk_vbox_new (false, 1);
+  gtk_container_set_border_width (GTK_CONTAINER (vb), 3);
+  gtk_container_add (GTK_CONTAINER(frame), vb);
+
+  btn = gtk_check_button_new_with_label ("Use edge weights");
+  gtk_widget_set_name (GTK_WIDGET(btn), "MDS_WEIGHTS");
+  gtk_tooltips_set_tip (GTK_TOOLTIPS (ggv->tips), btn,
+    "The distance matrix for a graph is the minimum number of edges connecting any pair of nodes.  These distances can be weighted if an edge variable is supplied.",
+    NULL);
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (btn), false);
+  gtk_widget_set_sensitive (btn, ggv->mds_task == GraphLayout);
+  gtk_signal_connect (GTK_OBJECT (btn), "toggled",
+    GTK_SIGNAL_FUNC (ggv_edge_weights_cb), inst);
+  gtk_box_pack_start (GTK_BOX (vb), btn, true, true, 2);
+
+  btn = gtk_check_button_new_with_label ("Complete graph distances");
+  gtk_widget_set_name (GTK_WIDGET(btn), "MDS_COMPLETE");
+  gtk_tooltips_set_tip (GTK_TOOLTIPS (ggv->tips), btn,
+    "Fill in a missing D[i,j] using a shortest path algorithm when a path exists from i to j; if not checked, D[i,j] is treated as missing.",
+    NULL);
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(btn),
+    ggv->Dtarget_source == LinkDist);
+  gtk_widget_set_sensitive (btn, (ggv->mds_task == GraphLayout));
+  gtk_signal_connect (GTK_OBJECT (btn), "toggled",
+    GTK_SIGNAL_FUNC (ggv_complete_distances_cb), inst);
+  gtk_box_pack_start (GTK_BOX (vb), btn, true, true, 2);
+
+  label = gtk_label_new ("Task");
+  gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox, label);
+
 /*-- "Definition of D" controls --*/
 
   hbox = gtk_hbox_new (false, 1);
@@ -312,54 +403,23 @@ create_ggvis_window(ggvisd *ggv, PluginInstance *inst)
   vbox = gtk_vbox_new (false, 1);
   gtk_box_pack_start (GTK_BOX (hbox), vbox, false, false, 2);
 
-  /*-- Option menu: Use edge distances or an edge variable --*/
-  opt = gtk_option_menu_new ();
-  gtk_tooltips_set_tip (GTK_TOOLTIPS (tips), opt,
-    "To define the distance matrix D, use unweighted edges (typical for graphs) or the edge variable selected at right (typical for MDS data and weighted graphs)",
-    NULL);
-  populate_option_menu (opt, (gchar**) dsource_lbl,
-    sizeof (dsource_lbl) / sizeof (gchar *),
-    (GtkSignalFunc) ggv_dsource_cb, "PluginInst", inst);
-  gtk_box_pack_start (GTK_BOX (vbox), opt, false, false, 2);
-
-  btn = gtk_check_button_new_with_label ("Complete distances ");
-  gtk_tooltips_set_tip (GTK_TOOLTIPS (tips), btn,
-    "Fill in a missing D[i,j] using a shortest path algorithm when a path exists from i to j; by default, D[i,j] is treated as missing.",
-    NULL);
-  gtk_signal_connect (GTK_OBJECT (btn), "toggled",
-    GTK_SIGNAL_FUNC (ggv_complete_distances_cb), inst);
-  gtk_box_pack_start (GTK_BOX (vbox), btn, false, false, 2);
-
   /*-- include only edge sets.  --*/
   varnotebook = create_variable_notebook (hbox,
     GTK_SELECTION_SINGLE, all_vartypes, edgesets_only,
     (GtkSignalFunc) NULL, inst->gg);
-
+  swin = gtk_notebook_get_nth_page (GTK_NOTEBOOK (varnotebook), 0);
+  if (swin != NULL) {
+    ggv->clist_dist = (GtkCList *) GTK_BIN(swin)->child;
+    /* Initialize, selecting first variable */
+    if (ggv->mds_task == DissimAnalysis)
+      gtk_clist_select_row (ggv->clist_dist, 0, 0);
+  } else ggv->clist_dist = (GtkCList *) NULL;
 
   /*-- Report on D --*/
   hb = gtk_hbox_new (false, 1);
   gtk_box_pack_start (GTK_BOX (vbox), hb, false, false, 2);
 
-  /*
-   * create this button after the varnotebook, because it's
-   *   necessary to get hold of the notebook in the button callback
-  */
-  btn = gtk_button_new_with_label ("Compute D");
-  gtk_tooltips_set_tip (GTK_TOOLTIPS (tips), btn,
-    "Compute the new target distance matrix D.",
-    NULL);
-  gtk_object_set_data (GTK_OBJECT(btn), "notebook", varnotebook);
-  gtk_signal_connect (GTK_OBJECT (btn), "clicked",
-    GTK_SIGNAL_FUNC (ggv_compute_Dtarget_cb), inst);
-  gtk_box_pack_start (GTK_BOX (hb), btn, false, false, 2);
-
-  entry = gtk_entry_new ();
-  gtk_object_set_data (GTK_OBJECT(window), "DTARGET_ENTRY", entry);
-  gtk_entry_set_editable (GTK_ENTRY (entry), false);
-  gtk_entry_set_text (GTK_ENTRY (entry), "(uninitialized)");
-  gtk_box_pack_start (GTK_BOX (hb), entry, false, false, 2);
-
-  label = gtk_label_new ("Definition of D");
+  label = gtk_label_new ("Dist");
   gtk_notebook_append_page (GTK_NOTEBOOK (notebook), hbox, label);
 
 /*-- Run controls --*/
@@ -368,7 +428,7 @@ create_ggvis_window(ggvisd *ggv, PluginInstance *inst)
   gtk_container_set_border_width (GTK_CONTAINER (vbox), 2);
 
   /*-- table --*/
-  table = gtk_table_new (1, 2, false);
+  table = gtk_table_new (2, 2, false);
   gtk_container_set_border_width (GTK_CONTAINER (table), 2);
   gtk_box_pack_start (GTK_BOX (vbox), table, false, false, 1);
 
@@ -377,7 +437,7 @@ create_ggvis_window(ggvisd *ggv, PluginInstance *inst)
   /*-- MDS Dimension --*/
   label = gtk_label_new ("Dimension (k)");
   /*gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.0);*/
-  gtk_table_attach (GTK_TABLE (table), label, 1, 2, top, top+1,
+  gtk_table_attach (GTK_TABLE (table), label, 0, 1, top, top+1,
     (GtkAttachOptions) (GTK_FILL|GTK_EXPAND), 
     (GtkAttachOptions) (GTK_FILL|GTK_EXPAND),
     1, 1);
@@ -389,40 +449,55 @@ create_ggvis_window(ggvisd *ggv, PluginInstance *inst)
   gtk_widget_set_usize (GTK_WIDGET (hscale), 150, 30);
   ggvis_scale_set_default_values (GTK_SCALE(hscale));
   gtk_scale_set_digits (GTK_SCALE(hscale), 0);
-  gtk_table_attach (GTK_TABLE (table), hscale, 0, 1, top, top+1,
+  gtk_table_attach (GTK_TABLE (table), hscale, 1, 2, top, top+1,
     (GtkAttachOptions) (GTK_FILL|GTK_EXPAND), 
     (GtkAttachOptions) (GTK_FILL|GTK_EXPAND),
     1, 1);
 
-  hbox = gtk_hbox_new (false, 1);
-  gtk_box_pack_start (GTK_BOX (vbox), hbox, false, false, 2);
-
-  /* Run, step, reinit and scramble in an hbox */
-
-  /*-- run --*/
-  btn = gtk_check_button_new_with_label ("Run MDS");
-  gtk_widget_set_name (btn, "RunMDS");
-  gtk_widget_set_sensitive (btn, false);
-  gtk_box_pack_start (GTK_BOX (hbox), btn, false, false, 2);
-  gtk_signal_connect (GTK_OBJECT (btn), "clicked",
-    GTK_SIGNAL_FUNC (mds_run_cb), inst);
+  top++;
 
+  /* Stepsize */
+  label = gtk_label_new ("Step size");
+  /*gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.0);*/
+  gtk_table_attach (GTK_TABLE (table), label, 0, 1, top, top+1,
+    (GtkAttachOptions) (GTK_FILL|GTK_EXPAND), 
+    (GtkAttachOptions) (GTK_FILL|GTK_EXPAND),
+    1, 1);
 
   adj = gtk_adjustment_new (0.01, 0.0001, 0.2, 0.02, 0.2, 0.10);
   gtk_signal_connect (GTK_OBJECT (adj), "value_changed",
     GTK_SIGNAL_FUNC (ggv_stepsize_cb), inst);
   hscale = gtk_hscale_new (GTK_ADJUSTMENT (adj));
   gtk_widget_set_name (hscale, "stepsize_scale");
-  gtk_tooltips_set_tip (GTK_TOOLTIPS (tips), hscale,
+  gtk_tooltips_set_tip (GTK_TOOLTIPS (ggv->tips), hscale,
     "Stepsize", NULL);
   gtk_widget_set_usize (GTK_WIDGET (hscale), 100, 30);
   ggvis_scale_set_default_values (GTK_SCALE(hscale));
   gtk_scale_set_digits (GTK_SCALE(hscale), 4);
+  /*
   gtk_box_pack_start (GTK_BOX (hbox), hscale, true, true, 2);
+  */
+  gtk_table_attach (GTK_TABLE (table), hscale, 1, 2, top, top+1,
+    (GtkAttachOptions) (GTK_FILL|GTK_EXPAND), 
+    (GtkAttachOptions) (GTK_FILL|GTK_EXPAND),
+    1, 1);
 
-  btn = gtk_button_new_with_label ("Step");
+  /* Run and step */
+
+  hbox = gtk_hbox_new (false, 1);
+  gtk_box_pack_start (GTK_BOX (vbox), hbox, false, false, 2);
+
+  /*-- run --*/
+  btn = gtk_check_button_new_with_label ("Run MDS");
+  gtk_widget_set_name (btn, "RunMDS");
+
+  gtk_box_pack_start (GTK_BOX (hbox), btn, false, false, 2);
+  gtk_signal_connect (GTK_OBJECT (btn), "clicked",
+    GTK_SIGNAL_FUNC (mds_run_cb), inst);
+
+  btn = gtk_button_new_with_label ("Step once");
   gtk_widget_set_name (btn, "Step");
-  gtk_widget_set_sensitive (btn, false);
+  gtk_widget_set_sensitive (btn, false); /* make sensitive after running */
   gtk_box_pack_start (GTK_BOX (hbox), btn, false, false, 2);
   gtk_signal_connect (GTK_OBJECT (btn), "clicked",
     GTK_SIGNAL_FUNC (mds_step_cb), inst);
@@ -541,14 +616,11 @@ create_ggvis_window(ggvisd *ggv, PluginInstance *inst)
   isotonic_mix_adj = gtk_adjustment_new (100.0, 0.0, 101.0, 1.0, 1.0, 1.0);
   gtk_signal_connect (GTK_OBJECT (isotonic_mix_adj), "value_changed",
     GTK_SIGNAL_FUNC (ggv_Dtarget_power_cb), inst);
+  menu = gtk_option_menu_get_menu (GTK_OPTION_MENU(metric_opt));
+  children = gtk_container_children (GTK_CONTAINER(menu));
 
-{
-  GtkWidget *menu = gtk_option_menu_get_menu (GTK_OPTION_MENU(metric_opt));
-  GList *children = gtk_container_children (GTK_CONTAINER(menu));
-  GList *l;
-  GtkWidget *child;
-  for (l = children; l; l = l->next) {
-    child = (GtkWidget *) l->data;
+  for (list = children; list; list = list->next) {
+    child = (GtkWidget *) list->data;
     gtk_object_set_data (GTK_OBJECT(child), "label", label); 
     gtk_object_set_data (GTK_OBJECT(child), "hscale", hscale);
     gtk_object_set_data (GTK_OBJECT(child),
@@ -556,7 +628,6 @@ create_ggvis_window(ggvisd *ggv, PluginInstance *inst)
     gtk_object_set_data (GTK_OBJECT(child),
       "Dtarget_adj", Dtarget_adj); 
   }
-}
 
   /*-- Weight power --*/
   top++;
@@ -655,20 +726,58 @@ create_ggvis_window(ggvisd *ggv, PluginInstance *inst)
   gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
   gtk_container_add (GTK_CONTAINER(frame), vbox);
 
-  btn = gtk_check_button_new_with_label ("Use brush groups");
-  gtk_signal_connect (GTK_OBJECT (btn), "toggled",
-    GTK_SIGNAL_FUNC (ggv_brush_groupsp_cb), inst);
-  gtk_box_pack_start (GTK_BOX (vbox), btn, false, false, 2);
-
-  opt = gtk_option_menu_new ();
-  populate_option_menu (opt, (gchar**) groups_lbl,
-    sizeof (groups_lbl) / sizeof (gchar *),
-    (GtkSignalFunc) ggv_brush_groups_opt_cb, "PluginInst", inst);
-  gtk_box_pack_start (GTK_BOX (vbox), opt, false, false, 2);
+  for (i=0; i<3; i++) {
+    if (i == 0) {
+      radio = gtk_radio_button_new_with_label (NULL, groups_lbl[i]);
+      GTK_TOGGLE_BUTTON (radio)->active = TRUE;
+      gtk_widget_set_name (radio, "GROUPS_OFF");
+    } else {
+      group = gtk_radio_button_group (GTK_RADIO_BUTTON (radio));
+      radio = gtk_radio_button_new_with_label (group, groups_lbl[i]);
+    }
+    gtk_object_set_data (GTK_OBJECT(radio), "PluginInst", inst);
+    gtk_signal_connect (GTK_OBJECT (radio), "toggled",
+      GTK_SIGNAL_FUNC (ggv_groups_cb), GINT_TO_POINTER(i));
+    gtk_box_pack_start (GTK_BOX (vbox), radio, TRUE, TRUE, 0);
+  }
 
   label = gtk_label_new ("Groups");
   gtk_notebook_append_page (GTK_NOTEBOOK (notebook), frame, label);
 
+  /*-- Anchor tab --*/
+  frame = gtk_frame_new ("Anchor");
+  gtk_container_set_border_width (GTK_CONTAINER (frame), 5);
+
+  hbox = gtk_hbox_new (false, 2);
+  gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
+  gtk_container_add (GTK_CONTAINER(frame), hbox);
+
+  vbox = gtk_vbox_new (false, 2);
+  gtk_box_pack_start (GTK_BOX (hbox), vbox, false, false, 0);
+
+  for (i=0; i<3; i++) {
+    if (i == 0) {
+      radio = gtk_radio_button_new_with_label (NULL, anchor_lbl[i]);
+      gtk_widget_set_name (radio, "ANCHOR_OFF");
+      GTK_TOGGLE_BUTTON (radio)->active = TRUE;
+    } else {
+      group = gtk_radio_button_group (GTK_RADIO_BUTTON (radio));
+      radio = gtk_radio_button_new_with_label (group, anchor_lbl[i]);
+    }
+    gtk_object_set_data (GTK_OBJECT(radio), "PluginInst", inst);
+    gtk_signal_connect (GTK_OBJECT (radio), "toggled",
+      GTK_SIGNAL_FUNC (ggv_anchor_cb), GINT_TO_POINTER(i));
+    gtk_box_pack_start (GTK_BOX (vbox), radio, TRUE, TRUE, 0);
+  }
+
+  /* Add symbols */
+  ggv->anchor_frame =  gtk_frame_new ("Symbols in use");
+  gtk_box_pack_start (GTK_BOX (hbox), ggv->anchor_frame, TRUE, TRUE, 0);
+  ggv_anchor_table_build (inst);
+
+  label = gtk_label_new ("Anchor");
+  gtk_notebook_append_page (GTK_NOTEBOOK (notebook), frame, label);
+
   /*-- Sensitivity Analysis --*/
   frame = gtk_frame_new ("Sensitivity analysis");
   gtk_container_set_border_width (GTK_CONTAINER (frame), 5);
@@ -769,21 +878,112 @@ create_ggvis_window(ggvisd *ggv, PluginInstance *inst)
   gtk_widget_show_all (window);
 }
 
-
+/*
+ * This one is called if the ggvis window is closed while
+ * ggobi is still running.  It should disconnect signals,
+ * because otherwise there's a problem when another routine
+ * (eg GraphLayout) adds a datad.  (This doesn't happen to be
+ * working, but it should!)
+ */
 void close_ggvis_window(GtkWidget *w, PluginInstance *inst)
 {
+ guint id;
+ 
+  if (inst->data) {
+    GtkWidget *window = GTK_WIDGET(inst->data);
+    ggobid *gg = inst->gg;
+    ggvisd *ggv = ggvisFromInst (inst);
+
+    GtkWidget *clist_node = widget_find_by_name (window, "nodeset");
+    GtkWidget *clist_edge = widget_find_by_name (window, "edgeset");
+
+    /* I'm definitely getting the right clists; I've checked */
+/*
+    if (id) gtk_signal_disconnect (GTK_OBJECT(gg), id);
+    if (id) gtk_signal_disconnect (GTK_OBJECT(gg), id);
+*/
+
+    /* Disconnect signals; this isn't working.  Don't know why. */
+
+    /*gtk_signal_connect (GTK_OBJECT (gg), "datad_added",
+     (GtkSignalFunc) ggv_clist_datad_added_cb,
+     GTK_OBJECT (clist));*/
+    id = gtk_signal_lookup ("datad_added", GTK_TYPE_GGOBI);
+    if (id && clist_node != NULL && clist_edge != NULL) {
+      gtk_signal_disconnect_by_func (GTK_OBJECT(gg),
+        (GtkSignalFunc) ggv_clist_datad_added_cb,
+        (gpointer) GTK_OBJECT(clist_node));
+      gtk_signal_disconnect_by_func (GTK_OBJECT(gg),
+        (GtkSignalFunc) ggv_clist_datad_added_cb,
+        (gpointer) GTK_OBJECT(clist_edge));
+    }
+
+    /*  gtk_signal_connect (GTK_OBJECT(gg),
+	"clusters_changed", clusters_changed_cb, inst); */
+    id = gtk_signal_lookup ("clusters_changed", GTK_TYPE_GGOBI);
+    if (id) {
+      gtk_signal_disconnect_by_func (GTK_OBJECT(gg),
+        (GtkSignalFunc) clusters_changed_cb,
+        (gpointer) inst);
+    }
+
+    /* The signals don't seem to be disappearing, and
+       I can't disconnect a signal by id */
+
+    /*
+     * This is the window, so it should serve to destroy
+     * all the child widgets.
+    */
+    gtk_widget_destroy ((GtkWidget *) inst->data);
+
+    ggv_free (ggv);
+  }
   inst->data = NULL;
 }
 
+/*
+ * This one is called when ggobi shuts down; it doesn't
+ * need to do much of anything, I think.  Should it free
+ * its data, though?  Perhaps.  When I try freeing the pixmaps
+ * at that time, though, I get an error message.  - dfs
+ */
 void closeWindow(ggobid *gg, GGobiPluginInfo *plugin, PluginInstance *inst)
 {
   if (inst->data) {
-    ggvisd *ggv = ggvisFromInst (inst);
-    /*
-    gtk_signal_disconnect_by_func(GTK_OBJECT(inst->data),
-      GTK_SIGNAL_FUNC (close_ggvis_window), inst);
-    */
-    gtk_widget_destroy ((GtkWidget *) inst->data);
+    inst->data = NULL;
   }
 }
 
+void
+ggv_free (ggvisd *ggv) {
+  /* unref the pixmaps */
+  /*
+  if (GTK_OBJECT(ggv->dissim->pix)->ref_count > 1)
+    gdk_pixmap_unref (ggv->dissim->pix);
+  if (GTK_OBJECT(ggv->stressplot_pix)->ref_count > 1)
+    gdk_pixmap_unref (ggv->stressplot_pix);
+  */
+
+  arrayd_free (&ggv->Dtarget, 0, 0);
+  arrayd_free (&ggv->pos, 0, 0);
+
+  vectord_free (&ggv->stressvalues);
+  vectord_free (&ggv->stressvalues);
+
+  g_free (ggv->dissim);
+  vectorb_free (&ggv->dissim->bars_included);
+  vectori_free (&ggv->dissim->bins);
+  vectorb_free (&ggv->anchor_group);
+  vectord_free (&ggv->pos_mean);
+  vectord_free (&ggv->weights);
+  vectord_free (&ggv->rand_sel);
+  vectord_free (&ggv->trans_dist);
+  vectord_free (&ggv->config_dist);
+  vectori_free (&ggv->point_status);
+  vectori_free (&ggv->trans_dist_index);
+  vectori_free (&ggv->bl);
+  vectord_free (&ggv->bl_w);
+  arrayd_free (&ggv->gradient, 0, 0);
+
+  g_free (ggv);
+}
