@@ -1,12 +1,17 @@
 /* display.c */
 /*
-    This software may only be used by you under license from AT&T Corp.
-    ("AT&T").  A copy of AT&T's Source Code Agreement is available at
-    AT&T's Internet website having the URL:
-    <http://www.research.att.com/areas/stat/ggobi/license.html>
-    If you received this software without first entering into a license
-    with AT&T, you have an infringing copy of this software and cannot use
-    it without violating AT&T's intellectual property rights.
+ * ggobi
+ * Copyright (C) AT&T, Duncan Temple Lang, Dianne Cook 1999-2005
+ *
+ * ggobi is free software; you may use, redistribute, and/or modify it
+ * under the terms of the Common Public License, which is distributed
+ * with the source code and displayed on the ggobi web site, 
+ * www.ggobi.org.  For more information, contact the authors:
+ *
+ *   Deborah F. Swayne   dfs@research.att.com
+ *   Di Cook             dicook@iastate.edu
+ *   Duncan Temple Lang  duncan@wald.ucdavis.edu
+ *   Andreas Buja        andreas.buja@wharton.upenn.edu
 */
 
 #include <gtk/gtk.h>
@@ -166,11 +171,10 @@ display_options_cb (GtkCheckMenuItem *w, guint action)
 
 
 /*
-
-We need to allow people to programmatically change a setting and force the update. 
-The current framework is all based on GUI events and so we don't update the GUI components 
-here as we assume they are set appropriately.  A Model View Controller approach is needed.
-
+We need to allow people to programmatically change a setting and force
+the update.  The current framework is all based on GUI events and so
+we don't update the GUI components here as we assume they are set
+appropriately.  A Model View Controller approach is needed.
 */
 void
 set_display_option(gboolean active, guint action, displayd *display, ggobid *gg)
