@@ -1,3 +1,19 @@
+/* plugin.c */
+/*
+ * ggobi
+ * Copyright (C) AT&T, Duncan Temple Lang, Dianne Cook 1999-2005
+ *
+ * ggobi is free software; you may use, redistribute, and/or modify it
+ * under the terms of the Common Public License, which is distributed
+ * with the source code and displayed on the ggobi web site, 
+ * www.ggobi.org.  For more information, contact the authors:
+ *
+ *   Deborah F. Swayne   dfs@research.att.com
+ *   Di Cook             dicook@iastate.edu
+ *   Duncan Temple Lang  duncan@wald.ucdavis.edu
+ *   Andreas Buja        andreas.buja@wharton.upenn.edu
+*/
+
 #include "plugin.h"
 
 #include <stdio.h>
@@ -444,7 +460,8 @@ closePlugins(ggobid *gg)
     plugin = (PluginInstance *) el->data;
     if(plugin->info->info.g->onClose) {
       DLFUNC f =  getPluginSymbol(plugin->info->info.g->onClose, plugin->info->details);
-      f(gg, plugin->info, plugin);
+      if (f)
+        f(gg, plugin->info, plugin);
     }
     tmp = el;
     el = el->next;
