@@ -1,3 +1,19 @@
+/* read_xml.c */
+/*
+ * ggobi
+ * Copyright (C) AT&T, Duncan Temple Lang, Dianne Cook 1999-2005
+ *
+ * ggobi is free software; you may use, redistribute, and/or modify it
+ * under the terms of the Common Public License, which is distributed
+ * with the source code and displayed on the ggobi web site, 
+ * www.ggobi.org.  For more information, contact the authors:
+ *
+ *   Deborah F. Swayne   dfs@research.att.com
+ *   Di Cook             dicook@iastate.edu
+ *   Duncan Temple Lang  duncan@wald.ucdavis.edu
+ *   Andreas Buja        andreas.buja@wharton.upenn.edu
+*/
+
 #include <libxml/parserInternals.h>
 
 /*
@@ -595,8 +611,8 @@ setEdgePartners (XMLParserData *parserData)
   /*-- Assume that we have no edges from i to i --*/
 
   /*
-   *  Before setting partners, check for duplicate edges.  If we find
-   *  one, bail out -- we don't handle them correctly, and we don't
+   * Before setting partners, check for duplicate edges.  If we find
+   * one, bail out -- we don't handle them correctly, and we don't
    * want them around.
   */
 
@@ -672,6 +688,9 @@ void endXMLElement(void *user_data, const xmlChar *name)
     break;
 
     case EDGE:
+      if (data->current_element < data->current_data->ncols) {
+        ggobi_XML_error_handler (data, "Not enough elements\n");
+      }
       data->current_record++;
     break;
     case RECORD:
@@ -681,6 +700,9 @@ void endXMLElement(void *user_data, const xmlChar *name)
          tag in the case where record elements have been individually
          tagged, and it does that without confusion. */
       setRecordValues(data, data->recordString, data->recordStringLength);
+      if (data->current_element < data->current_data->ncols) {
+        ggobi_XML_error_handler (data, "Not enough elements\n");
+      }
       data->current_record++;
       resetRecordInfo(data);
     break;
@@ -1326,19 +1348,20 @@ setRecordValues (XMLParserData *data, const xmlChar *line, gint len)
   tmp = strtok((gchar*) line, " \t\n");
 
   while (tmp && (tmp < (gchar *) (line + len))) {
+    /*
+    g_printerr("current element %d token %s\n", data->current_element,
+    tmp);
+    */
     if(setRecordValue(tmp, d, data) == false)
         return(false);
     data->current_element++;
     tmp = strtok (NULL, " \t\n");
   }
+  /*
   if (data->current_element < d->ncols) {
     ggobi_XML_error_handler (data, "Not enough elements\n");
-    /*
-    g_printerr ("Record %d has insufficient elements: %d < %d\n",
-		data->current_record, data->current_element,
-		d->ncols);
-    */
   }
+  */
 
 
   applyRandomUniforms(d, data);
