@@ -1,12 +1,17 @@
 /* sp_plot.c */
 /*
-    This software may only be used by you under license from AT&T Corp.
-    ("AT&T").  A copy of AT&T's Source Code Agreement is available at
-    AT&T's Internet website having the URL:
-    <http://www.research.att.com/areas/stat/ggobi/license.html>
-    If you received this software without first entering into a license
-    with AT&T, you have an infringing copy of this software and cannot use
-    it without violating AT&T's intellectual property rights.
+ * ggobi
+ * Copyright (C) AT&T, Duncan Temple Lang, Dianne Cook 1999-2005
+ *
+ * ggobi is free software; you may use, redistribute, and/or modify it
+ * under the terms of the Common Public License, which is distributed
+ * with the source code and displayed on the ggobi web site, 
+ * www.ggobi.org.  For more information, contact the authors:
+ *
+ *   Deborah F. Swayne   dfs@research.att.com
+ *   Di Cook             dicook@iastate.edu
+ *   Duncan Temple Lang  duncan@wald.ucdavis.edu
+ *   Andreas Buja        andreas.buja@wharton.upenn.edu
 */
 
 #include <string.h>
@@ -779,6 +784,8 @@ splot_add_record_cues (splotd *sp, GdkDrawable *drawable, ggobid *gg) {
   else if (mode == MOVEPTS)
      splot_add_movepts_cues (sp, drawable, d->nearest_point, true, gg);
   else if (mode == EDGEED)
+    /* If I want to draw in the color of nearest_point, I should pass
+       it in here -- dfs*/
     splot_add_edgeedit_cues (sp, drawable, d->nearest_point, true, gg);
  
 
