@@ -28,7 +28,7 @@ The authors can be contacted at the following email addresses:
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
-#ifndef Darwin
+#if !defined __APPLE__ && !defined __GNUC__
 #include <malloc.h>
 #endif
 
@@ -169,7 +169,7 @@ void center (array_f *data)
   }
 }
 
-gint pca (array_f *pdata, void *param, gfloat *val)
+gint pca (array_f *pdata, void *param, gfloat *val, gpointer userData)
 { gint i, j;
 
   center (pdata);
